==> mule-oauth-client-api-2.4.12-20251027.195557-5-sources.jar: org/mule/oauth/client/api/builder/OAuthClientCredentialsDancerBuilder.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.oauth.client.api.builder;

import org.mule.api.annotation.NoImplement;
import org.mule.oauth.client.api.ClientCredentialsOAuthDancer;
import org.mule.oauth.client.api.listener.ClientCredentialsListener;

import java.util.Map;
import java.util.function.Supplier;

/**
 * Builder that allows to configure the attributes for the client credentials grant type.
 *
 * @since 1.0
 */
@NoImplement
public interface OAuthClientCredentialsDancerBuilder extends OAuthDancerBuilder<ClientCredentialsOAuthDancer> {

  /**
   * There are OAuth implementations that require or allow extra query parameters to be sent when calling the token URL of the
   * OAS.
   *
   * @param customParameters a {@link Map} the extra parameters to be sent with the token request to {@link #tokenUrl(String)}.
   * @return this builder
   */
  OAuthClientCredentialsDancerBuilder customParameters(Map<String, String> customParameters);

  /**
   * There are OAuth implementations that require or allow extra headers to be sent when calling the token URL of the OAS.
   *
   * @param customHeaders a {@link Map} the extra headers to be sent with the token request to {@link #tokenUrl(String)}.
   * @return this builder
   */
  OAuthClientCredentialsDancerBuilder customHeaders(Map<String, String> customHeaders);

  /**
   * Adds the {@code customBodyParameters} to the body of the token url request.
   *
   * @param customBodyParameters a {@link Supplier} for the custom parameters
   * @return {@code this} builder
   * @throws IllegalArgumentException if {@code customBodyParameters} is {@code null}
   * @since 2.0.0
   */
  OAuthClientCredentialsDancerBuilder customBodyParameters(Map<String, String> customBodyParameters);

  /**
   * Adds the {@code listener}. Listeners will be invoked in the same order as they were added
   *
   * @param listener the {@link ClientCredentialsListener} to be added
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   */
  OAuthClientCredentialsDancerBuilder addListener(ClientCredentialsListener listener);

  /**
   * @param encodeClientCredentialsInBody If @{code true}, the client id and client secret will be sent in the request body.
   *                                      Otherwise, they will be sent as basic authentication.
   * @return this builder
   * @deprecated since 4.2.0. Use {@link OAuthClientCredentialsDancerBuilder#withClientCredentialsIn(ClientCredentialsLocation)}
   *             instead.
   */
  @Deprecated
  OAuthClientCredentialsDancerBuilder encodeClientCredentialsInBody(boolean encodeClientCredentialsInBody);

}

==> mule-oauth-client-api-2.6.0-20250812.150717-5-sources.jar: org/mule/oauth/client/api/builder/OAuthClientCredentialsDancerBuilder.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.oauth.client.api.builder;

import org.mule.api.annotation.NoImplement;
import org.mule.oauth.client.api.ClientCredentialsOAuthDancer;
import org.mule.oauth.client.api.listener.ClientCredentialsListener;

import java.util.Map;
import java.util.function.Supplier;

/**
 * Builder that allows to configure the attributes for the client credentials grant type.
 *
 * @since 1.0
 */
@NoImplement
public interface OAuthClientCredentialsDancerBuilder extends OAuthDancerBuilder<ClientCredentialsOAuthDancer> {

  /**
   * There are OAuth implementations that require or allow extra query parameters to be sent when calling the token URL of the
   * OAS.
   *
   * @param customParameters a {@link Map} the extra parameters to be sent with the token request to {@link #tokenUrl(String)}.
   * @return this builder
   */
  OAuthClientCredentialsDancerBuilder customParameters(Map<String, String> customParameters);

  /**
   * There are OAuth implementations that require or allow extra headers to be sent when calling the token URL of the OAS.
   *
   * @param customHeaders a {@link Map} the extra headers to be sent with the token request to {@link #tokenUrl(String)}.
   * @return this builder
   */
  OAuthClientCredentialsDancerBuilder customHeaders(Map<String, String> customHeaders);

  /**
   * Adds the {@code customBodyParameters} to the body of the token url request.
   *
   * @param customBodyParameters a {@link Supplier} for the custom parameters
   * @return {@code this} builder
   * @throws IllegalArgumentException if {@code customBodyParameters} is {@code null}
   * @since 2.0.0
   */
  OAuthClientCredentialsDancerBuilder customBodyParameters(Map<String, String> customBodyParameters);

  /**
   * Adds the {@code listener}. Listeners will be invoked in the same order as they were added
   *
   * @param listener the {@link ClientCredentialsListener} to be added
   * @throws IllegalArgumentException if the {@code listener} is {@code null}
   */
  OAuthClientCredentialsDancerBuilder addListener(ClientCredentialsListener listener);

  /**
   * @param encodeClientCredentialsInBody If @{code true}, the client id and client secret will be sent in the request body.
   *                                      Otherwise, they will be sent as basic authentication.
   * @return this builder
   * @deprecated since 1.0. Use {@link OAuthClientCredentialsDancerBuilder#withClientCredentialsIn(ClientCredentialsLocation)}
   *             instead.
   */
  @Deprecated(since = "1.0")
  OAuthClientCredentialsDancerBuilder encodeClientCredentialsInBody(boolean encodeClientCredentialsInBody);

}
